@@ -7,17 +7,12 @@ def retry(exceptions_to_catch, num_retries=5, timeout=0, hook=None):
         def wrapper(*args, **kwargs):
             timeout_is_func = hasattr(timeout, '__call__')
 
-            if isinstance(exceptions_to_catch, Exception):
-                exceptions = (exceptions_to_catch, )
-            else:
-                exceptions = exceptions_to_catch
-
             for i in xrange(num_retries + 1):
                 attempt_number = i + 1
 
                 try:
                     return func(*args, **kwargs)
-                except exceptions as e:
+                except exceptions_to_catch as e:
                     if i == num_retries:
                         raise e
 
